<?php
/**
 * Physiotherapy Lite Theme Customizer
 *
 * @package Physiotherapy Lite
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */

function physiotherapy_lite_custom_controls() {
	load_template( trailingslashit( get_template_directory() ) . '/inc/custom-controls.php' );
}
add_action( 'customize_register', 'physiotherapy_lite_custom_controls' );

function physiotherapy_lite_customize_register( $wp_customize ) {

	load_template( trailingslashit( get_template_directory() ) . 'inc/customize-homepage/class-customize-homepage.php' );

	//add home page setting pannel
	$wp_customize->add_panel( 'physiotherapy_lite_panel_id', array(
	    'priority' => 10,
	    'capability' => 'edit_theme_options',
	    'theme_supports' => '',
	    'title' => __( 'VW Settings', 'physiotherapy-lite' ),
	) );

	// Layout
	$wp_customize->add_section( 'physiotherapy_lite_left_right', array(
    	'title'      => __( 'General Settings', 'physiotherapy-lite' ),
		'panel' => 'physiotherapy_lite_panel_id'
	) );

	$wp_customize->add_setting('physiotherapy_lite_theme_options',array(
        'default' => __('Right Sidebar','physiotherapy-lite'),
        'sanitize_callback' => 'physiotherapy_lite_sanitize_choices'
	));
	$wp_customize->add_control('physiotherapy_lite_theme_options',array(
        'type' => 'select',
        'label' => __('Post Sidebar Layout','physiotherapy-lite'),
        'description' => __('Here you can change the sidebar layout for posts. ','physiotherapy-lite'),
        'section' => 'physiotherapy_lite_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','physiotherapy-lite'),
            'Right Sidebar' => __('Right Sidebar','physiotherapy-lite'),
            'One Column' => __('One Column','physiotherapy-lite'),
            'Three Columns' => __('Three Columns','physiotherapy-lite'),
            'Four Columns' => __('Four Columns','physiotherapy-lite'),
            'Grid Layout' => __('Grid Layout','physiotherapy-lite')
        ),
	) );

	$wp_customize->add_setting('physiotherapy_lite_page_layout',array(
        'default' => __('One Column','physiotherapy-lite'),
        'sanitize_callback' => 'physiotherapy_lite_sanitize_choices'
	));
	$wp_customize->add_control('physiotherapy_lite_page_layout',array(
        'type' => 'select',
        'label' => __('Page Sidebar Layout','physiotherapy-lite'),
        'description' => __('Here you can change the sidebar layout for pages. ','physiotherapy-lite'),
        'section' => 'physiotherapy_lite_left_right',
        'choices' => array(
            'Left Sidebar' => __('Left Sidebar','physiotherapy-lite'),
            'Right Sidebar' => __('Right Sidebar','physiotherapy-lite'),
            'One Column' => __('One Column','physiotherapy-lite')
        ),
	) );

	//Top Bar
	$wp_customize->add_section( 'physiotherapy_lite_topbar', array(
    	'title'      => __( 'Top Bar Settings', 'physiotherapy-lite' ),
		'panel' => 'physiotherapy_lite_panel_id'
	) );

	$wp_customize->add_setting('physiotherapy_lite_call',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	$wp_customize->add_control('physiotherapy_lite_call',array(
		'label'	=> __('Add Phone Number','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( '+00 1234 567 890', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_topbar',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'physiotherapy_lite_header_cart',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
    ));  
    $wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_header_cart',array(
      	'label' => esc_html__( 'Show / Hide Cart','physiotherapy-lite' ),
      	'section' => 'physiotherapy_lite_topbar'
    )));
	
	$wp_customize->add_setting( 'physiotherapy_lite_header_search',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
    ));  
    $wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_header_search',array(
      	'label' => esc_html__( 'Show / Hide Search','physiotherapy-lite' ),
      	'section' => 'physiotherapy_lite_topbar'
    )));
    
	//Slider
	$wp_customize->add_section( 'physiotherapy_lite_slidersettings' , array(
    	'title'      => __( 'Slider Settings', 'physiotherapy-lite' ),
		'panel' => 'physiotherapy_lite_panel_id'
	) );

	$wp_customize->add_setting( 'physiotherapy_lite_slider_arrows',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
    ));  
    $wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_slider_arrows',array(
      	'label' => esc_html__( 'Show / Hide Slider','physiotherapy-lite' ),
      	'section' => 'physiotherapy_lite_slidersettings'
    )));

	for ( $count = 1; $count <= 4; $count++ ) {

		$wp_customize->add_setting( 'physiotherapy_lite_slider_page' . $count, array(
			'default'           => '',
			'sanitize_callback' => 'physiotherapy_lite_sanitize_dropdown_pages'
		) );
		$wp_customize->add_control( 'physiotherapy_lite_slider_page' . $count, array(
			'label'    => __( 'Select Slider Page', 'physiotherapy-lite' ),
			'description' => __('Slider image size (1600 x 600)','physiotherapy-lite'),
			'section'  => 'physiotherapy_lite_slidersettings',
			'type'     => 'dropdown-pages'
		) );
	}
 
	//Services
	$wp_customize->add_section('physiotherapy_lite_services',array(
		'title'	=> __('Services Section','physiotherapy-lite'),
		'panel' => 'physiotherapy_lite_panel_id',
	));	

	$wp_customize->add_setting('physiotherapy_lite_section_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('physiotherapy_lite_section_text',array(
		'label'	=> __('Section Text','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'Our Services', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_services',
		'type'=> 'text'
	));	

	$wp_customize->add_setting('physiotherapy_lite_section_title',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('physiotherapy_lite_section_title',array(
		'label'	=> __('Section Title','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'OUR PHYSIOTHERAPY', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_services',
		'type'=> 'text'
	));	

	$categories = get_categories();
		$cat_posts = array();
			$i = 0;
			$cat_posts[]='Select';	
		foreach($categories as $category){
			if($i==0){
			$default = $category->slug;
			$i++;
		}
		$cat_posts[$category->slug] = $category->name;
	}

	$wp_customize->add_setting('physiotherapy_lite_services_category',array(
		'default'	=> 'select',
		'sanitize_callback' => 'sanitize_text_field',
	));
	$wp_customize->add_control('physiotherapy_lite_services_category',array(
		'type'    => 'select',
		'choices' => $cat_posts,
		'label' => __('Select Category to display Latest Post','physiotherapy-lite'),
		'section' => 'physiotherapy_lite_services',
	));

	//Content Craetion
	$wp_customize->add_section( 'physiotherapy_lite_content_section' , array(
    	'title' => __( 'Customize Home Page Settings', 'physiotherapy-lite' ),
		'priority' => null,
		'panel' => 'physiotherapy_lite_panel_id'
	) );

	$wp_customize->add_setting('physiotherapy_lite_content_creation_main_control', array(
		'sanitize_callback' => 'esc_html',
	) );

	$homepage= get_option( 'page_on_front' );

	$wp_customize->add_control(	new Physiotherapy_Lite_Content_Creation( $wp_customize, 'physiotherapy_lite_content_creation_main_control', array(
		'options' => array(
			esc_html__( 'First select static page in homepage setting for front page.Below given edit button is to customize Home Page. Just click on the edit option, add whatever elements you want to include in the homepage, save the changes and you are good to go.','physiotherapy-lite' ),
		),
		'section' => 'physiotherapy_lite_content_section',
		'button_url'  => admin_url( 'post.php?post='.$homepage.'&action=edit'),
		'button_text' => esc_html__( 'Edit', 'physiotherapy-lite' ),
	) ) );

	//Footer Text
	$wp_customize->add_section('physiotherapy_lite_footer',array(
		'title'	=> __('Footer Settings','physiotherapy-lite'),
		'panel' => 'physiotherapy_lite_panel_id',
	));	
	
	$wp_customize->add_setting('physiotherapy_lite_footer_text',array(
		'default'=> '',
		'sanitize_callback'	=> 'sanitize_text_field'
	));	
	$wp_customize->add_control('physiotherapy_lite_footer_text',array(
		'label'	=> __('Copyright Text','physiotherapy-lite'),
		'input_attrs' => array(
            'placeholder' => __( 'Copyright 2019, .....', 'physiotherapy-lite' ),
        ),
		'section'=> 'physiotherapy_lite_footer',
		'type'=> 'text'
	));

	$wp_customize->add_setting( 'physiotherapy_lite_footer_scroll',array(
    	'default' => 1,
      	'transport' => 'refresh',
      	'sanitize_callback' => 'physiotherapy_lite_switch_sanitization'
    ));  
    $wp_customize->add_control( new Physiotherapy_Lite_Toggle_Switch_Custom_Control( $wp_customize, 'physiotherapy_lite_footer_scroll',array(
      	'label' => esc_html__( 'Show / Hide Scroll to Top','physiotherapy-lite' ),
      	'section' => 'physiotherapy_lite_footer'
    )));
}

add_action( 'customize_register', 'physiotherapy_lite_customize_register' );

load_template( trailingslashit( get_template_directory() ) . '/inc/logo/logo-resizer.php' );

/**
 * Singleton class for handling the theme's customizer integration.
 *
 * @since  1.0.0
 * @access public
 */
final class physiotherapy_lite_Customize {

	/**
	 * Returns the instance.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return object
	 */
	public static function get_instance() {

		static $instance = null;

		if ( is_null( $instance ) ) {
			$instance = new self;
			$instance->setup_actions();
		}

		return $instance;
	}

	/**
	 * Constructor method.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function __construct() {}

	/**
	 * Sets up initial actions.
	 *
	 * @since  1.0.0
	 * @access private
	 * @return void
	 */
	private function setup_actions() {

		// Register panels, sections, settings, controls, and partials.
		add_action( 'customize_register', array( $this, 'sections' ) );

		// Register scripts and styles for the controls.
		add_action( 'customize_controls_enqueue_scripts', array( $this, 'enqueue_control_scripts' ), 0 );
	}

	/**
	 * Sets up the customizer sections.
	 *
	 * @since  1.0.0
	 * @access public
	 * @param  object  $manager
	 * @return void
	*/
	public function sections( $manager ) {

		// Load custom sections.
		load_template( trailingslashit( get_template_directory() ) . '/inc/section-pro.php' );

		// Register custom section types.
		$manager->register_section_type( 'Physiotherapy_Lite_Customize_Section_Pro' );

		// Register sections.
		$manager->add_section( new Physiotherapy_Lite_Customize_Section_Pro( $manager,'example_1', array(
			'priority'   => 9,
			'title'    => esc_html__( 'Physiotherapy Pro', 'physiotherapy-lite' ),
			'pro_text' => esc_html__( 'UPGRADE PRO', 'physiotherapy-lite' ),
			'pro_url'  => esc_url('https://www.vwthemes.com/themes/physiotherapy-wordpress-theme/'),
		) )	);
	}

	/**
	 * Loads theme customizer CSS.
	 *
	 * @since  1.0.0
	 * @access public
	 * @return void
	 */
	public function enqueue_control_scripts() {

		wp_enqueue_script( 'physiotherapy-lite-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/js/customize-controls.js', array( 'customize-controls' ) );

		wp_enqueue_style( 'physiotherapy-lite-customize-controls', trailingslashit( get_template_directory_uri() ) . '/assets/css/customize-controls.css' );
	}
}

// Doing this customizer thang!
physiotherapy_lite_Customize::get_instance();